# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/mpi.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.plugins.kubeflow import common_pb2 as flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/mpi.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n#flyteidl/plugins/kubeflow/mpi.proto\x12\x19\x66lyteidl.plugins.kubeflow\x1a\x19\x66lyteidl/core/tasks.proto\x1a&flyteidl/plugins/kubeflow/common.proto\"\x95\x02\n\x1a\x44istributedMPITrainingTask\x12U\n\x0fworker_replicas\x18\x01 \x01(\x0b\x32<.flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec\x12W\n\x11launcher_replicas\x18\x02 \x01(\x0b\x32<.flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec\x12\x38\n\nrun_policy\x18\x03 \x01(\x0b\x32$.flyteidl.plugins.kubeflow.RunPolicy\x12\r\n\x05slots\x18\x04 \x01(\x05\"\xc4\x01\n!DistributedMPITrainingReplicaSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12+\n\tresources\x18\x03 \x01(\x0b\x32\x18.flyteidl.core.Resources\x12@\n\x0erestart_policy\x18\x04 \x01(\x0e\x32(.flyteidl.plugins.kubeflow.RestartPolicy\x12\x0f\n\x07\x63ommand\x18\x05 \x03(\tB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2.DESCRIPTOR,])




_DISTRIBUTEDMPITRAININGTASK = _descriptor.Descriptor(
  name='DistributedMPITrainingTask',
  full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.worker_replicas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='launcher_replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.launcher_replicas', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_policy', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.run_policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slots', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingTask.slots', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=411,
)


_DISTRIBUTEDMPITRAININGREPLICASPEC = _descriptor.Descriptor(
  name='DistributedMPITrainingReplicaSpec',
  full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart_policy', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.restart_policy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec.command', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=610,
)

_DISTRIBUTEDMPITRAININGTASK.fields_by_name['worker_replicas'].message_type = _DISTRIBUTEDMPITRAININGREPLICASPEC
_DISTRIBUTEDMPITRAININGTASK.fields_by_name['launcher_replicas'].message_type = _DISTRIBUTEDMPITRAININGREPLICASPEC
_DISTRIBUTEDMPITRAININGTASK.fields_by_name['run_policy'].message_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RUNPOLICY
_DISTRIBUTEDMPITRAININGREPLICASPEC.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
_DISTRIBUTEDMPITRAININGREPLICASPEC.fields_by_name['restart_policy'].enum_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RESTARTPOLICY
DESCRIPTOR.message_types_by_name['DistributedMPITrainingTask'] = _DISTRIBUTEDMPITRAININGTASK
DESCRIPTOR.message_types_by_name['DistributedMPITrainingReplicaSpec'] = _DISTRIBUTEDMPITRAININGREPLICASPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistributedMPITrainingTask = _reflection.GeneratedProtocolMessageType('DistributedMPITrainingTask', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDMPITRAININGTASK,
  __module__ = 'flyteidl.plugins.kubeflow.mpi_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedMPITrainingTask)
  ))
_sym_db.RegisterMessage(DistributedMPITrainingTask)

DistributedMPITrainingReplicaSpec = _reflection.GeneratedProtocolMessageType('DistributedMPITrainingReplicaSpec', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDMPITRAININGREPLICASPEC,
  __module__ = 'flyteidl.plugins.kubeflow.mpi_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedMPITrainingReplicaSpec)
  ))
_sym_db.RegisterMessage(DistributedMPITrainingReplicaSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
