# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/external_plugin_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/service/external_plugin_service.proto',
  package='flyteidl.service',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/service'),
  serialized_pb=_b('\n.flyteidl/service/external_plugin_service.proto\x12\x10\x66lyteidl.service\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1d\x66lyteidl/core/interface.proto\"\x84\x01\n\x11TaskCreateRequest\x12)\n\x06inputs\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\x12-\n\x08template\x18\x02 \x01(\x0b\x32\x1b.flyteidl.core.TaskTemplate\x12\x15\n\routput_prefix\x18\x03 \x01(\t\"$\n\x12TaskCreateResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"3\n\x0eTaskGetRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"e\n\x0fTaskGetResponse\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.flyteidl.service.State\x12*\n\x07outputs\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"6\n\x11TaskDeleteRequest\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"\x14\n\x12TaskDeleteResponse*^\n\x05State\x12\x15\n\x11RETRYABLE_FAILURE\x10\x00\x12\x15\n\x11PERMANENT_FAILURE\x10\x01\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tSUCCEEDED\x10\x04\x32\x9f\x02\n\x15\x45xternalPluginService\x12Y\n\nCreateTask\x12#.flyteidl.service.TaskCreateRequest\x1a$.flyteidl.service.TaskCreateResponse\"\x00\x12P\n\x07GetTask\x12 .flyteidl.service.TaskGetRequest\x1a!.flyteidl.service.TaskGetResponse\"\x00\x12Y\n\nDeleteTask\x12#.flyteidl.service.TaskDeleteRequest\x1a$.flyteidl.service.TaskDeleteResponse\"\x00\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/serviceb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_core_dot_interface__pb2.DESCRIPTOR,])

_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='flyteidl.service.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RETRYABLE_FAILURE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMANENT_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=563,
  serialized_end=657,
)
_sym_db.RegisterEnumDescriptor(_STATE)

State = enum_type_wrapper.EnumTypeWrapper(_STATE)
RETRYABLE_FAILURE = 0
PERMANENT_FAILURE = 1
PENDING = 2
RUNNING = 3
SUCCEEDED = 4



_TASKCREATEREQUEST = _descriptor.Descriptor(
  name='TaskCreateRequest',
  full_name='flyteidl.service.TaskCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.service.TaskCreateRequest.inputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='flyteidl.service.TaskCreateRequest.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_prefix', full_name='flyteidl.service.TaskCreateRequest.output_prefix', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=289,
)


_TASKCREATERESPONSE = _descriptor.Descriptor(
  name='TaskCreateResponse',
  full_name='flyteidl.service.TaskCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskCreateResponse.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=291,
  serialized_end=327,
)


_TASKGETREQUEST = _descriptor.Descriptor(
  name='TaskGetRequest',
  full_name='flyteidl.service.TaskGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.service.TaskGetRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskGetRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=329,
  serialized_end=380,
)


_TASKGETRESPONSE = _descriptor.Descriptor(
  name='TaskGetResponse',
  full_name='flyteidl.service.TaskGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.service.TaskGetResponse.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.service.TaskGetResponse.outputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=483,
)


_TASKDELETEREQUEST = _descriptor.Descriptor(
  name='TaskDeleteRequest',
  full_name='flyteidl.service.TaskDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_type', full_name='flyteidl.service.TaskDeleteRequest.task_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='flyteidl.service.TaskDeleteRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=485,
  serialized_end=539,
)


_TASKDELETERESPONSE = _descriptor.Descriptor(
  name='TaskDeleteResponse',
  full_name='flyteidl.service.TaskDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=561,
)

_TASKCREATEREQUEST.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_TASKCREATEREQUEST.fields_by_name['template'].message_type = flyteidl_dot_core_dot_tasks__pb2._TASKTEMPLATE
_TASKGETRESPONSE.fields_by_name['state'].enum_type = _STATE
_TASKGETRESPONSE.fields_by_name['outputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
DESCRIPTOR.message_types_by_name['TaskCreateRequest'] = _TASKCREATEREQUEST
DESCRIPTOR.message_types_by_name['TaskCreateResponse'] = _TASKCREATERESPONSE
DESCRIPTOR.message_types_by_name['TaskGetRequest'] = _TASKGETREQUEST
DESCRIPTOR.message_types_by_name['TaskGetResponse'] = _TASKGETRESPONSE
DESCRIPTOR.message_types_by_name['TaskDeleteRequest'] = _TASKDELETEREQUEST
DESCRIPTOR.message_types_by_name['TaskDeleteResponse'] = _TASKDELETERESPONSE
DESCRIPTOR.enum_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TaskCreateRequest = _reflection.GeneratedProtocolMessageType('TaskCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKCREATEREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskCreateRequest)
  ))
_sym_db.RegisterMessage(TaskCreateRequest)

TaskCreateResponse = _reflection.GeneratedProtocolMessageType('TaskCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKCREATERESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskCreateResponse)
  ))
_sym_db.RegisterMessage(TaskCreateResponse)

TaskGetRequest = _reflection.GeneratedProtocolMessageType('TaskGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKGETREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskGetRequest)
  ))
_sym_db.RegisterMessage(TaskGetRequest)

TaskGetResponse = _reflection.GeneratedProtocolMessageType('TaskGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKGETRESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskGetResponse)
  ))
_sym_db.RegisterMessage(TaskGetResponse)

TaskDeleteRequest = _reflection.GeneratedProtocolMessageType('TaskDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _TASKDELETEREQUEST,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskDeleteRequest)
  ))
_sym_db.RegisterMessage(TaskDeleteRequest)

TaskDeleteResponse = _reflection.GeneratedProtocolMessageType('TaskDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _TASKDELETERESPONSE,
  __module__ = 'flyteidl.service.external_plugin_service_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.service.TaskDeleteResponse)
  ))
_sym_db.RegisterMessage(TaskDeleteResponse)


DESCRIPTOR._options = None

_EXTERNALPLUGINSERVICE = _descriptor.ServiceDescriptor(
  name='ExternalPluginService',
  full_name='flyteidl.service.ExternalPluginService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=660,
  serialized_end=947,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateTask',
    full_name='flyteidl.service.ExternalPluginService.CreateTask',
    index=0,
    containing_service=None,
    input_type=_TASKCREATEREQUEST,
    output_type=_TASKCREATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTask',
    full_name='flyteidl.service.ExternalPluginService.GetTask',
    index=1,
    containing_service=None,
    input_type=_TASKGETREQUEST,
    output_type=_TASKGETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTask',
    full_name='flyteidl.service.ExternalPluginService.DeleteTask',
    index=2,
    containing_service=None,
    input_type=_TASKDELETEREQUEST,
    output_type=_TASKDELETERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTERNALPLUGINSERVICE)

DESCRIPTOR.services_by_name['ExternalPluginService'] = _EXTERNALPLUGINSERVICE

# @@protoc_insertion_point(module_scope)
