# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/tensorflow.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.plugins.kubeflow import common_pb2 as flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/tensorflow.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n*flyteidl/plugins/kubeflow/tensorflow.proto\x12\x19\x66lyteidl.plugins.kubeflow\x1a\x19\x66lyteidl/core/tasks.proto\x1a&flyteidl/plugins/kubeflow/common.proto\"\xf2\x02\n!DistributedTensorflowTrainingTask\x12\\\n\x0fworker_replicas\x18\x01 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12X\n\x0bps_replicas\x18\x02 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12[\n\x0e\x63hief_replicas\x18\x03 \x01(\x0b\x32\x43.flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec\x12\x38\n\nrun_policy\x18\x04 \x01(\x0b\x32$.flyteidl.plugins.kubeflow.RunPolicy\"\xba\x01\n(DistributedTensorflowTrainingReplicaSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\r\n\x05image\x18\x02 \x01(\t\x12+\n\tresources\x18\x03 \x01(\x0b\x32\x18.flyteidl.core.Resources\x12@\n\x0erestart_policy\x18\x04 \x01(\x0e\x32(.flyteidl.plugins.kubeflow.RestartPolicyB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2.DESCRIPTOR,])




_DISTRIBUTEDTENSORFLOWTRAININGTASK = _descriptor.Descriptor(
  name='DistributedTensorflowTrainingTask',
  full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.worker_replicas', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ps_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.ps_replicas', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chief_replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.chief_replicas', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_policy', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask.run_policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=511,
)


_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC = _descriptor.Descriptor(
  name='DistributedTensorflowTrainingReplicaSpec',
  full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restart_policy', full_name='flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec.restart_policy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=700,
)

_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['worker_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['ps_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['chief_replicas'].message_type = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_DISTRIBUTEDTENSORFLOWTRAININGTASK.fields_by_name['run_policy'].message_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RUNPOLICY
_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC.fields_by_name['resources'].message_type = flyteidl_dot_core_dot_tasks__pb2._RESOURCES
_DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC.fields_by_name['restart_policy'].enum_type = flyteidl_dot_plugins_dot_kubeflow_dot_common__pb2._RESTARTPOLICY
DESCRIPTOR.message_types_by_name['DistributedTensorflowTrainingTask'] = _DISTRIBUTEDTENSORFLOWTRAININGTASK
DESCRIPTOR.message_types_by_name['DistributedTensorflowTrainingReplicaSpec'] = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistributedTensorflowTrainingTask = _reflection.GeneratedProtocolMessageType('DistributedTensorflowTrainingTask', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDTENSORFLOWTRAININGTASK,
  __module__ = 'flyteidl.plugins.kubeflow.tensorflow_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedTensorflowTrainingTask)
  ))
_sym_db.RegisterMessage(DistributedTensorflowTrainingTask)

DistributedTensorflowTrainingReplicaSpec = _reflection.GeneratedProtocolMessageType('DistributedTensorflowTrainingReplicaSpec', (_message.Message,), dict(
  DESCRIPTOR = _DISTRIBUTEDTENSORFLOWTRAININGREPLICASPEC,
  __module__ = 'flyteidl.plugins.kubeflow.tensorflow_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.DistributedTensorflowTrainingReplicaSpec)
  ))
_sym_db.RegisterMessage(DistributedTensorflowTrainingReplicaSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
