# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/kubeflow/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/kubeflow/common.proto',
  package='flyteidl.plugins.kubeflow',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n&flyteidl/plugins/kubeflow/common.proto\x12\x19\x66lyteidl.plugins.kubeflow\"\xac\x01\n\tRunPolicy\x12\x43\n\x10\x63lean_pod_policy\x18\x01 \x01(\x0e\x32).flyteidl.plugins.kubeflow.CleanPodPolicy\x12\"\n\x1attl_seconds_after_finished\x18\x02 \x01(\x05\x12\x1f\n\x17\x61\x63tive_deadline_seconds\x18\x03 \x01(\x05\x12\x15\n\rbackoff_limit\x18\x04 \x01(\x05*c\n\rRestartPolicy\x12\x18\n\x14RESTART_POLICY_NEVER\x10\x00\x12\x1d\n\x19RESTART_POLICY_ON_FAILURE\x10\x01\x12\x19\n\x15RESTART_POLICY_ALWAYS\x10\x02*`\n\x0e\x43leanPodPolicy\x12\x18\n\x14\x43LEANPOD_POLICY_NONE\x10\x00\x12\x1b\n\x17\x43LEANPOD_POLICY_RUNNING\x10\x01\x12\x17\n\x13\x43LEANPOD_POLICY_ALL\x10\x02\x42\x39Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)

_RESTARTPOLICY = _descriptor.EnumDescriptor(
  name='RestartPolicy',
  full_name='flyteidl.plugins.kubeflow.RestartPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_NEVER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_ON_FAILURE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESTART_POLICY_ALWAYS', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=244,
  serialized_end=343,
)
_sym_db.RegisterEnumDescriptor(_RESTARTPOLICY)

RestartPolicy = enum_type_wrapper.EnumTypeWrapper(_RESTARTPOLICY)
_CLEANPODPOLICY = _descriptor.EnumDescriptor(
  name='CleanPodPolicy',
  full_name='flyteidl.plugins.kubeflow.CleanPodPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEANPOD_POLICY_ALL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=345,
  serialized_end=441,
)
_sym_db.RegisterEnumDescriptor(_CLEANPODPOLICY)

CleanPodPolicy = enum_type_wrapper.EnumTypeWrapper(_CLEANPODPOLICY)
RESTART_POLICY_NEVER = 0
RESTART_POLICY_ON_FAILURE = 1
RESTART_POLICY_ALWAYS = 2
CLEANPOD_POLICY_NONE = 0
CLEANPOD_POLICY_RUNNING = 1
CLEANPOD_POLICY_ALL = 2



_RUNPOLICY = _descriptor.Descriptor(
  name='RunPolicy',
  full_name='flyteidl.plugins.kubeflow.RunPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clean_pod_policy', full_name='flyteidl.plugins.kubeflow.RunPolicy.clean_pod_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl_seconds_after_finished', full_name='flyteidl.plugins.kubeflow.RunPolicy.ttl_seconds_after_finished', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active_deadline_seconds', full_name='flyteidl.plugins.kubeflow.RunPolicy.active_deadline_seconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backoff_limit', full_name='flyteidl.plugins.kubeflow.RunPolicy.backoff_limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=242,
)

_RUNPOLICY.fields_by_name['clean_pod_policy'].enum_type = _CLEANPODPOLICY
DESCRIPTOR.message_types_by_name['RunPolicy'] = _RUNPOLICY
DESCRIPTOR.enum_types_by_name['RestartPolicy'] = _RESTARTPOLICY
DESCRIPTOR.enum_types_by_name['CleanPodPolicy'] = _CLEANPODPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunPolicy = _reflection.GeneratedProtocolMessageType('RunPolicy', (_message.Message,), dict(
  DESCRIPTOR = _RUNPOLICY,
  __module__ = 'flyteidl.plugins.kubeflow.common_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.kubeflow.RunPolicy)
  ))
_sym_db.RegisterMessage(RunPolicy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
